Coverage for cards/materials.py: 100%

1"""

2 NASTRAN material Cards Collection

3"""

4 import logging

5 import re

6 from collections import defaultdict

7

8 from nastranio.cardslib import SimpleCard

9 from nastranio.decorators import material

10

11

12@material

13 class MAT1(SimpleCard):

14 """

15 Isotropic Material Property Definition

16 Defines the material properties for linear isotropic materials.

17

18 ref: NX Nastran 12 Quick Reference Guide 15-2 (p.1968)

19 """

20

21 COMMENTS_KEY = "Material"

22

23 TABLE = """

24 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 |

25 |------+-----+----+----+-------+-----+---+------+----+----|

26 | MAT1 | MID | E | G | NU | RHO | A | TREF | GE | |

27 | | ST | SC | SS | MCSID | | | | | |

28 """

29

30 DEFAULTS = {

31 "G": None,

32 "NU": None,

33 "RHO": 0.0,

34 "A": 0.0,

35 "TREF": 0.0,

36 "GE": None,

37 "ST": None,

38 "SC": None,

39 "SS": None,

40 "MCSID": None,

41 }

42

43

44@material

45 class MAT8(SimpleCard):

46 """

47 Shell Element Orthotropic Material Property Definition

48 Defines the material property for an orthotropic material for isoparametric shell

49 elements.

50

51 ref: NX Nastran 12 Quick Reference Guide 15-19 (p.1985)

52 """

53

54 COMMENTS_KEY = "Material"

55

56 TABLE = """

57 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 |

58 |------+-----+-----+------+------+-----+-----+-----+-----+----|

59 | MAT8 | MID | E1 | E2 | NU12 | G12 | G1Z | G2Z | RHO | |

60 | | A1 | A2 | TREF | Xt | Xc | Yt | Yc | S | |

61 | | GE | F12 | STRN | | | | | | |

62

63 """